"""
Example of using two SNAP wireless nodes to replace a RS-232 cable
Edit this script to specify the OTHER node's address, and load it into a node
Node addresses are the last three bytes of the MAC Address
MAC Addresses can be read off of the SNAP Engine sticker
For example, a node with MAC Address 001C2C1E 86001B67 is address 001B67
In SNAPpy format this would be address "\x00\x1B\x67"

Modified code written by J.C. Woltz
Further modified by Solarbotics Sept. 2011

Hardware used: Freeduino (or Arduino Duemilanove) + Arduino Xbee shield +
Solarbotics Synapse-to-Xbee Adapter Kit + Syanpse Wireless RF100 module

Xbee Shield jumpers must be set to "XBEE" for serial communication to get to Arduino chip
GPIO 9 is attached to the Arduino Reset via resistor R1 and transistor T1
"""
from synapse.switchboard import *
from synapse.platforms import *
otherNodeAddr = "\x00\x00\x00"      # <= put the address of the PC-side node here
@setHook(HOOK_STARTUP)
def startupEvent():
    saveNvParam(13, 0)              #Buffering Timeout, Default value: 5
    saveNvParam(14, 110)            #Buffering Threshold, Default value: 75
    saveNvParam(15, 5)             #Inter-character Timeout settings, Default value: 0
    initUart(1, 57600)              #set UART1 baud rate to bootloader speed of Arduino Duemilanove/Freeduino 57600kbps
    flowControl(1, False)           #set UART1 flow control to off 
    crossConnect(DS_UART1, DS_TRANSPARENT)  #set up UART1 for Transparent serial communication
    ucastSerial(otherNodeAddr)      #set the destination node of our serial transmission
    setPinDir(9, True)              #set node GPIO 9 to Output 
    writePin(9, True)               #set pin High 
   
